# Test Coverage Report

Generated: Sun 2013-03-24 21:11 CET

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 458 | 349 | 53 | 86.2%
calendarium.__init__ | 1 | 1 | 0 | 100.0%
calendarium.constants | 5 | 4 | 1 | 100.0%
calendarium.forms | 70 | 52 | 6 | 81.2%
calendarium.models | 160 | 107 | 23 | 78.1%
calendarium.templatetags.calendarium_tags | 14 | 10 | 4 | 100.0%
calendarium.tests.test_app.models | 7 | 5 | 2 | 100.0%
calendarium.utils | 20 | 18 | 2 | 100.0%
calendarium.views | 168 | 146 | 12 | 93.6%
calendarium.widgets | 13 | 6 | 3 | 60.0%

Excluded packages and modules
Error packages and modules